/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Carsten Driesner <carsten.driesner@open-xchange.com>
 */

define('io.ox/office/baseframework/utils/errorcontext', function () {

    'use strict';

    // static class ErrorContext ==============================================

    var // the exported ErrorContext class
        ErrorContext = {
            GENERAL:          '', // no specific context
            CREATEDOC:        'CREATEDOC',
            LOAD:             'LOAD',
            TEXT:             'TEXT',
            PRESENTATION:     'PRESENTATION',
            SPREADSHEET:      'SPREADSHEET',
            SAVE:             'SAVE',
            SAVEAS:           'SAVEAS',
            CLOSE:            'CLOSE',
            RENAME:           'RENAME',
            DOWNLOAD:         'DOWNLOAD',
            OFFLINE:          'OFFLINE',
            CONNECTION:       'CONNECTION',
            SYNCHRONIZATION:  'SYNCHRONIZATION',
            FLUSH:            'FLUSH',
            READONLY:         'READONLY',
            RESTOREDOC:       'RESTOREDOC'
        };

    // exports ================================================================

    return ErrorContext;

});
